#!/usr/bin/env python
# encoding: utf-8
# ====================================================
#   Copyright (C)2019 All rights reserved.
#
#   Author        : Xin-Xin MA
#   Email         : xxmawhu@163.com
#   File Name     : argv.py
#   Created Time  : 2019-09-19 19:35
#   Last Modified : 2019-09-19 19:47
#   Describe      :
#
# ====================================================
"""
core: set the numbers of processes
"""
import sys
opt = []
argv = []
core = 200
tmpFile = ['tmp']
#for i in sys.argv[1:]:
#    if i[0] == '-':
#        opt.append(i)
#    else:
#        argv.append(i)
